@@ -10,19 +10,21 @@ use Readonly;
 Readonly::Array our @EXPORT_OK => qw(check_array_object check_isa
 	check_number check_number_of_items check_required);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub check_array_object {
 	my ($self, $key, $class, $class_name) = @_;
 
-	if ($self->{$key}) {
-		if (ref $self->{$key} ne 'ARRAY') {
-			err "Parameter '".$key."' must be a array.";
-		} else {
-			foreach my $obj (@{$self->{$key}}) {
-				if (! $obj->isa($class)) {
-					err $class_name." isn't '".$class."' object.";
-				}
+	if (! exists $self->{$key}) {
+		return;
+	}
+
+	if (ref $self->{$key} ne 'ARRAY') {
+		err "Parameter '".$key."' must be a array.";
+	} else {
+		foreach my $obj (@{$self->{$key}}) {
+			if (! $obj->isa($class)) {
+				err $class_name." isn't '".$class."' object.";
 			}
 		}
 	}
@@ -43,6 +45,10 @@ sub check_isa {
 sub check_number {
 	my ($self, $key) = @_;
 
+	if (! exists $self->{$key}) {
+		return;
+	}
+
 	if ($self->{$key} !~ m/^-?\d+$/ms) {
 		err "Parameter '$key' must be a number.";
 	}
@@ -91,7 +97,7 @@ Mo::utils - Mo utilities.
 
 =head1 SYNOPSIS
 
- use Mo::utils qw(check_array_object check_isa check_number check_required);
+ use Mo::utils qw(check_array_object check_isa check_number check_number_of_items check_required);
 
  check_array_object($self, $key, $class, $class_name);
  check_isa($self, $key, $class);
@@ -370,6 +376,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
